@@ -30,6 +30,9 @@ class MCursor(object):
         self.__idx = 0
         self.__cursor_dead = False
 
+    def __len__(self):
+        return self.__mongo_cursor.count()
+
     def __iter__(self):
         self.__idx = 0
         return self
@@ -94,7 +97,7 @@ class MCursor(object):
         '''
         try:
             n = self.__mongo_cursor.next()
-            o = self.__cls(data=n, is_new=False)
+            o = self.__cls.load(**n)
             self.__loaded.append(o)
             self.__idx += 1
             return o
@@ -103,7 +106,7 @@ class MCursor(object):
 
     def _die(self):
         self.__cursor_dead = True
-        self.__mongo_cursor.__die()
+        self.__mongo_cursor.close()
         raise StopIteration()
 
 
@@ -131,6 +134,8 @@ class MList(list):
         
         :param value: The value to append to the list
         '''
+        if isinstance(value, MObject):
+            value = value.id
         list.append(self, value)
         self._update_delta()
 
@@ -143,6 +148,8 @@ class MList(list):
         return result
 
     def __setitem__(self, idx, value):
+        if isinstance(value, MObject):
+            value = value.id
         list.__setitem__(self, idx, value)
         self._update_delta()
 
@@ -178,6 +185,8 @@ class MDict(dict):
         dict.__init__(self, **kwargs)
 
     def __setitem__(self, key, value):
+        if isinstance(value, MObject):
+            value = value.id
         dict.__setitem__(self, key, value)
         self._update_delta()
 
@@ -214,7 +223,13 @@ class MObject(object):
     '''
 
     MONGO_ID = True
-    ''' Hello'''
+    ''' Does this object use an ObjectId for the _id field? '''
+
+    USE_DATE_CREATED = True
+    ''' Automatically add a `date_created` field to newly created objects '''
+
+    USE_DATE_MODIFIED = True
+    ''' Automatically add and update a `date_modified` field when updating objects '''
 
     DEFAULT_VALUES = {}
     ''' ``dict`` of default values for instance attributes. For instance
@@ -254,10 +269,10 @@ class MObject(object):
 
     def __init__(self, data=None, is_new=True, **kwargs):
         """ Create an instance of an ``MObject``.
-        
+
         Attributes for the new object can be defined by passing in a ``dict``
         as the `data` parameter or by using keyword arguments.
-        
+
         :param dict data: dictionary of attribute for the object
         :param bool is_new: is the object new (i.e. not loaded from the database)
         """
@@ -274,6 +289,13 @@ class MObject(object):
             for k, v in kwargs.iteritems():
                 setattr(self, k, v)
 
+    def intialize(self):
+        """ Called after the ``__init__`` method. Override this
+        in your models to do any preprocessing you want at load time.
+        """
+        pass
+
+
     def __delattr__(self, k):
         if k in self.BELONGS_TO:
             # TODO: should we actually delete the owner object?
@@ -304,9 +326,10 @@ class MObject(object):
         # TODO: move this to the BelongsTo class
         if k in self.BELONGS_TO:
             related, foreign_key, key2 = BelongsTo.parse_attrs(self, self.BELONGS_TO[k], k)
-            k = key2
             if isinstance(v, MObject):
-                v = v.id
+                self._m__relations[k] = BelongsTo(v, self, related, k, foreign_key)
+                k = key2
+                v = getattr(v, foreign_key)
 
         if isinstance(v, MList):
             v = list(v)
@@ -336,6 +359,7 @@ class MObject(object):
         if not raw:
             raw_k = k
             if k in self.BELONGS_TO and (k not in self._m__relations or not isinstance(self._m__relations[k], BelongsTo)):
+                print 'loading', k
                 self._m__relations[k] = BelongsTo.load(self, k, self.BELONGS_TO[k])
             elif k in self.HAS_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], HasMany)):
                 self._m__relations[k] = HasMany.load(self, k, self.HAS_MANY[k])
@@ -407,9 +431,10 @@ class MObject(object):
             return True
         doc = self._m__delta
 
-        if '$set' not in doc:
-            doc['$set'] = {}
-        doc['$set']['date_modified'] = datetime.now()
+        if self.USE_DATE_MODIFIED:
+            if '$set' not in doc:
+                doc['$set'] = {}
+            doc['$set']['date_modified'] = datetime.now()
 
         collection = self._get_collection()
         logging.info(collection.full_name, 'update', query, doc)
@@ -446,8 +471,10 @@ class MObject(object):
             self.id = bson.ObjectId()
 
         now = datetime.now()
-        self.date_created = now
-        self.date_modified = now
+        if self.USE_DATE_CREATED:
+            self.date_created = now
+        if self.USE_DATE_MODIFIED:
+            self.date_modified = now
 
         collection = self._get_collection()
         logging.info(collection.full_name, 'save', self._m__data)
@@ -456,6 +483,17 @@ class MObject(object):
             self._m__is_new = False
         return success
 
+    @classmethod
+    def load(cls, **kwargs):
+        """ Method called when objects are loaded from the database.
+
+        ONLY called for objects loaded from the database. NOT for newly created objects.
+        See :meth:`create` method.
+
+        :param dict kwargs: Properties of the newly loaded object.
+        """
+        return cls(is_new=False, **kwargs)
+
     @classmethod
     def create(cls, **kwargs):
         ''' Create an automatically save a new instance of a model.
@@ -548,19 +586,19 @@ class MObject(object):
         collection = cls._get_collection()
 
         if kwargs.get('filter', True):
-            new_query = cls.DEFAULT_FILTER
+            new_query = dict(cls.DEFAULT_FILTER)
             new_query.update(query)
             query = new_query
 
         if _one:
-            logging.info(collection.full_name, 'find_one', query)
+            logging.info(' - '.join([collection.full_name, 'find_one', str(query)]))
             response = collection.find_one(query, **kwargs)
             if response:
                 if not kwargs.get('raw'):
-                    response = cls(data=response, is_new=False)
+                    response = cls.load(**response)
                 return response
         else:
-            logging.info(collection.full_name, 'find', query)
+            logging.info(' - '.join([collection.full_name, 'find', str(query)]))
             response = collection.find(query, **kwargs)
             if response:
                 if 'raw' in kwargs:
@@ -580,4 +618,5 @@ class MObject(object):
                 first = False
             return cls.connection(pluralize(''.join(collection)))
         return cls.connection(cls.COLLECTION)
+
     
\ No newline at end of file
